package com.ruoyi.cs.mapper;

import java.util.List;
import com.ruoyi.cs.domain.CsCustomerFollow;
import com.ruoyi.cs.domain.template.CsCustomerFollowTemplate;

/**
 * 回访客户记录Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-07
 */
public interface CsCustomerFollowMapper
{
    /**
     * 查询回访客户记录
     *
     * @param customerFollowId 回访客户记录主键
     * @return 回访客户记录
     */
    public CsCustomerFollow selectCsCustomerFollowByCustomerFollowId(String customerFollowId);

    /**
     * 查询回访客户记录列表
     *
     * @param csCustomerFollow 回访客户记录
     * @return 回访客户记录集合
     */
    public List<CsCustomerFollow> selectCsCustomerFollowList(CsCustomerFollow csCustomerFollow);

    /**
     * 新增回访客户记录
     *
     * @param csCustomerFollow 回访客户记录
     * @return 结果
     */
    public int insertCsCustomerFollow(CsCustomerFollow csCustomerFollow);

    /**
     * 修改回访客户记录
     *
     * @param csCustomerFollow 回访客户记录
     * @return 结果
     */
    public int updateCsCustomerFollow(CsCustomerFollow csCustomerFollow);

    /**
     * 删除回访客户记录
     *
     * @param customerFollowId 回访客户记录主键
     * @return 结果
     */
    public int deleteCsCustomerFollowByCustomerFollowId(String customerFollowId);

    /**
     * 批量删除回访客户记录
     *
     * @param customerFollowIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCsCustomerFollowByCustomerFollowIds(String[] customerFollowIds);

    /**
     * 批量新增回访客户记录
     *
     * @param list 回访客户记录
     * @return 结果
     */
    public int insertCsCustomerFollowBatch(List<CsCustomerFollowTemplate> list);
}
